% find variables with the highest correlation with the preference rating

[correlations, pvalues] = corrcoef(beerData);

%calculates a matrix of correlation coefficients for beerData

correlations(:,1) = 1:cols;
correlations(:,2:end-1) = [];
correlations(:,3) = abs(correlations(:,2));

%desc: correlations = [col #, coefficient, abs of coeffficient]
%sort the correlations by the strongest coefficients

correlations = sortrows(correlations,-3);

%p-values for testing the hypothesis of no correlation.  Each p-value is
%the probability of getting a correlation as large as the observed value by
%random chance, when the true correlation is zero.  If P(i,j) is small, say
%less than 0.05, then the correlation R(i,j) is significant.

pvalues(:,1) = 1:cols;
pvalues(:,2:end-1) = [];

%desc: correlations = [col #, pvalue]
%sort the pvalues by lowest pvalues

pvalues = sortrows(pvalues,2);

percent_explained = 100*pvalues/sum(pvalues);
pareto(percent_explained);

%find variables with the highest correlation with the preference rating
%Column,  Correlation,    P Value,   Description:
%    11,      -0.2934,    0.0047,      BU: Bitterness units. 
%    27,       0.2760,    0.0080,      2-Methyl-1-Butanol
%    15,      -0.2380,    0.0230,      FTU: Formazin turbidity units.
%    14,      -0.2089,    0.0468,      C02: Carbon dioxide.
%    20,      -0.2018,    0.0550,      N-Propanol
%    33,       0.1939,    0.0655,      Ethyl Octanoate
%    35,       0.1867,    0.0763,      Ethyl Decanoate
%    21,       0.1617,    0.1256,      Ethyl Acetate

