beerData = importdata('file1.txt');
load colNames.mat 

% This removes the columns 36, 37, 38 which correspond to liquid
% identification number, test number, and number of subjects rating the
% beer respectively.  It's easier to deal with the data as [inputs output]
% without having to deal with known noise as an input.
beerData = beerData(:,[1:35 39]);
colNames = colNames([1:35 39],:);

rows = size(beerData,1);
cols = size(beerData,2);

% Calculate the means for each column fill NaNs with 0 for this calculation
NaNs = isnan(beerData);
notNaNcount = sum(~NaNs);
beerData(NaNs) = 0;

columnTotal = sum(beerData);
columnMean = columnTotal ./ notNaNcount;

%replace the NaNs with their columnMeans so as not to greatly schew the
%distance when checking for neighbors
allMeans = repmat(columnMean, [rows, 1]);
beerData(NaNs) = allMeans(NaNs);

ranges = zeros(1, cols);
%find the range of each variable so we can normalize it
for i = 1:cols
    maximum = max(beerData(:,i));
    minimum = min(beerData(:,i));
    ranges(i) = maximum - minimum;
end

beerNorm = (beerData - repmat(min(beerData),rows,1))./repmat(ranges,rows,1);

%%replace the NaNs with the missing value from their closest matching row

%find the rows with NaNs
rowNaNs = sum(NaNs, 2);

%replace the NaNs with the average of their closest neighbors
for i = 1:rows
    
    %if there are no NaNs in the row there is nothing to replace
    if rowNaNs(i) == 0
        continue;
    end
    
    neighbors = findCloseRows(beerNorm, i);
    %desc: neighbors(i,:) == [row, distance]
    %desc: neighbors(i) == row
    
    close_row1 = beerData(neighbors(1),:);
    close_row2 = beerData(neighbors(2),:);
    
    %iterate over the missing elements in the target row
    for n = find(NaNs(i,:))
 
        avg = (close_row1(n) + close_row2(n))/2;
        beerData(i,n) = avg;
        
    end
    
end

%Ok now I've got the beerData with all the missing values replaced with
%the average of the 2 closest neighbor's values

%I would use this method for replacing missing values in my data to analyze
%but there are no missing values in that data so I can simply load that
to_analyze = importdata('2.23.txt');


